#ifndef NT2_INCLUDE_FUNCTIONS_INBTRUE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_INBTRUE_HPP_INCLUDED

#include <nt2/reduction/include/functions/inbtrue.hpp>

#endif
